#!/bin/bash

# Creates archive database schema and imports test data from dev DB (ssstestdb).
# PREREQUISITE: all containers must be running.
# TODO: create test fixtures that call this before tests, then cleans up afterward

# set password for db in container
export PGPASSWORD=docker

# remove any test data, including lookup tables, from last run
echo Deleting existing test data, if any....
psql -h 0.0.0.0 -U archive -p 54322 < archive_db_reset.sql

# find out if the archive DB schema has the tables we need
echo Adding necessary tables to archive if they're not already there....
table_found=$(psql -h 0.0.0.0 -U archive -p 54322 -c "\d execution_blocks")
[[ "$table_found" =~ 'Did not find any relation' ]] && psql -h 0.0.0.0 -U archive -p 54322 -a -q -f archive_schema.txt

# if the lookup tables haven't been populated, do so now
echo Populating lookup tables, if necessary....
spt=$(psql -h 0.0.0.0 -U archive -p 54322 -c "SELECT * FROM science_product_types")
[[ "$spt" =~ (0 rows) ]] && psql -h 0.0.0.0 -U archive -p 54322 -q < archive_lookups.sql

# get test data from dev DB; write it to importable text files
echo Grabbing test data from archive on ssstestdb....
./get_test_data.sh

# N.B.: FK constraints interfering w alma_ouses inserts, so we're skipping ALMA for now.

#----------------------
# populate data tables
#----------------------
echo Importing test data:
echo projects....
psql -h 0.0.0.0 -U archive -p 54322 -q -c "COPY projects FROM STDOUT" < projects.txt

echo filegroups....
psql -h 0.0.0.0 -U archive -p 54322 -q -c "COPY filegroups FROM STDOUT" < filegroups.txt

echo science products....
psql -h 0.0.0.0 -U archive -p 54322 -q -c "COPY science_products FROM STDOUT" < science_products.txt

# TODO when we're ready to tackle ALMA data:
# psql -h 0.0.0.0 -U archive -p 54322 -q -c "COPY alma_ouses FROM STDOUT" < alma_ouses.txt

echo execution blocks....
psql -h 0.0.0.0 -U archive -p 54322 -q -c "COPY execution_blocks FROM STDOUT" < execution_blocks.txt

echo files....
psql -h 0.0.0.0 -U archive -p 54322 -q -c "COPY files FROM STDOUT" < files.txt

echo Done!
