from __future__ import annotations

from typing import Dict, List

from workspaces.capability.helpers_interfaces import CapabilityStepIF, ParameterIF
from workspaces.products.schema_interfaces import FutureProductIF
from workspaces.workflow.schema_interfaces import WorkflowRequestIF


class CapabilityIF:
    id: int
    name: str
    steps: List[CapabilityStepIF]
    max_jobs: int

    def create_request(
        self, parameters: ParameterIF, future_products: FutureProductIF
    ) -> "CapabilityRequestIF":
        raise NotImplementedError


class CapabilityRequestIF:
    id: int
    state: str
    capability: CapabilityIF
    parameters: str
    future_products: str
    versions: List[CapabilityVersionIF]

    def __json__(self) -> Dict[str, str]:
        raise NotImplementedError


class CapabilityVersionIF:
    capability_request: CapabilityRequestIF
    version_number: int
    # eventually, the parameters should go here


class CapabilityExecutionIF:
    id: int
    capability_version: CapabilityVersionIF
    state: str
    current_step: int
    version: CapabilityVersionIF
    current_workflow_request_id: int
    steps: str
    capability: CapabilityIF
    capability_request: CapabilityRequestIF

    def __json__(self) -> Dict[str, str]:
        raise NotImplementedError

    def on_last_step(self) -> bool:
        raise NotImplementedError
